Changelog
---------


0.1.1 (2015-04-05)
******************

* Fix return value in `has_permission`
* Add Flask-SQLAlchemy example
* Improve test coverage

0.1.0 (2015-04-01)
******************

* First release
* Support for SQLAlchemy, Django, Peewee, and Pony
